Relatórios | OiRA

# Relatórios

Pode usar um relatório para:

- servir de elemento prova a fornecer às autoridades de supervisão;
- informar as pessoas pertinentes (trabalhadores, representantes para assuntos relacionados com a segurança, empregadores, peritos em segurança e saúde no trabalho, etc.);
- controlar e verificar se foram tomadas as medidas necessárias;
- registar eventuais revisões em caso de mudança de circunstâncias (novas máquinas/trabalhadores ou mudanças induzidas na sequência de investigações de acidentes, etc.).

Pode guardar o relatório no seu computador e imprimi-lo. Pode também alterá-lo ou adicionar mais informações. As alterações introduzidas num relatório que tenha descarregado para o seu computador NÃO serão guardadas na ferramenta OiRA.

## Tipos de relatório

Existem diferentes tipos de relatórios disponíveis consoante a sua finalidade. A lista de relatórios disponíveis para os instrumentos específicos depende das decisões tomadas pelo parceiro nacional OiRA/programador da ferramenta OiRA.

Os relatórios disponíveis.

### Relatório completo

Formato: Word / Office Open XML (.docx). Pode ser editado por si depois de descarregado.

Fornece: todas as informações e dados introduzidos por si durante todo o processo de avaliação de riscos.

Utilize-o para: fornecer um elemento comprovativo da realização de uma avaliação de riscos às autoridades de supervisão (por exemplo, à inspeção do trabalho).

### Plano de ação

Formato: Excel / Office Open XML (.xlsx). Pode ser editado por si depois de descarregado.

Fornece: informações sobre todas as medidas que tenciona implementar.

Utilize-o para:

- assegurar um acompanhamento ativo da execução das medidas por si definidas;
- gerir os problemas/riscos no seu local de trabalho (tarefas específicas, competências, responsabilidades, prazos).

### Quadro geral de riscos

Formato: Documento em formato portátil (.pdf) Não pode ser editado por si depois de descarregado.

Fornece: um quadro geral dos riscos identificados.

Utilize-o para:

- obter uma rápida visão geral da situação relativa aos riscos no seu local de trabalho;
- transmitir informações às pessoas relevantes.
- verificar se os riscos/medidas são devidamente geridos.

### Quadro geral de medidas

Formato: Documento em formato portátil (.pdf) Não pode ser editado por si depois de descarregado.

Fornece: um quadro geral das medidas a implementar.

Utilize-o para:

- obter uma rápida visão geral da situação relativa às medidas que decidiu implementar;
- transmitir informações às pessoas relevantes.
- verificar se os riscos/medidas são devidamente geridos.

Scroll to top Load toolbar…
Back

## 4-reports.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More